==> zebrautility-0.0.9.tar.gz: ios/Classes/Printer.swift <==
//
//  Printer.swift
//  Runner
//
//  Created by faranegar on 6/21/20.
//

import Foundation


class Printer{

    let connectedStr:String = "Connected"
    let disconnectedStr:String = "Disconnected"
    let disconnectingStr:String = "Disconnecting"
    let sendingDataStr:String = "Sending Data"
    let doneStr:String = "Done"
    var connection : ZebraPrinterConnection?
    var methodChannel : FlutterMethodChannel?
    var selectedIPAddress: String? = nil
    var selectedMacAddress: String? = nil
    
    static func getInsatnce(binaryMessenger : FlutterBinaryMessenger) -> Printer {
        var printer = Printer()
        printer.setMethodChannel(binaryMessenger: binaryMessenger)
        return printer
    }
    
    func discoveryPrinters(){
      let manager = EAAccessoryManager.shared()
      let devices = manager.connectedAccessories
      for d in devices {
        self.methodChannel?.invokeMethod("printerFound", arguments: d.name + ";B_" + d.serialNumber)
      }
        self.methodChannel?.invokeMethod("onPrinterDiscoveryDone", arguments: nil)
    }
    
    func setMethodChannel(binaryMessenger : FlutterBinaryMessenger) {
        self.methodChannel = FlutterMethodChannel(name: "ZebraPrinterObject" + toString(), binaryMessenger: binaryMessenger)
        self.methodChannel?.setMethodCallHandler({ (FlutterMethodCall,  FlutterResult) in
            let args = FlutterMethodCall.arguments
            let myArgs = args as? [String: Any]
            if(FlutterMethodCall.method == "print"){
                self.printData(data: myArgs?["Data"] as! NSString)
            } else if(FlutterMethodCall.method == "checkPermission"){
                FlutterResult(true)
            } else if(FlutterMethodCall.method == "disconnect"){
                DispatchQueue.global(qos: .utility).async {
                    self.disconnect()
                          }
            } else if(FlutterMethodCall.method == "isPrinterConnected") {
                     FlutterResult(self.isPrinterConnect())
            } else if(FlutterMethodCall.method == "discoverPrinters") {
                self.discoveryPrinters()
            } else if(FlutterMethodCall.method == "setSettings") {
                let settingCommand = myArgs?["SettingCommand"] as? NSString
                        self.setSettings(settings: settingCommand!)
            } else if(FlutterMethodCall.method == "connectToPrinter") {
                   let address = myArgs?["address"] as? String
                DispatchQueue.global(qos: .utility).async { self.connectToSelectPrinter(address: address!)
                             }
            }
        })
    }

    func toString() -> String{
        return String(UInt(bitPattern: ObjectIdentifier(self)))
    }
    
    func connectToSelectPrinter(address: String) -> Bool{
        selectedIPAddress = nil

        if(self.connection != nil){
            self.connection?.close()
            setStatus(message: disconnectedStr, color: "R")
        }
        if(address.starts(with: "B_")){
            self.connection = MfiBtPrinterConnection(serialNumber: address.replacingOccurrences(of: "B_", with: ""))

        }else {
        self.connection = TcpPrinterConnection(address: address, andWithPort: 9100)
        }
        Thread.sleep(forTimeInterval: 1)
        var isOpen = self.connection?.open()
             print("connection open ")
        if isOpen == true {
           Thread.sleep(forTimeInterval: 1)
            self.selectedIPAddress = address
            setStatus(message: connectedStr, color: "G")
            return true
        } else {
            setStatus(message: disconnectedStr, color: "R")
            return false
        }
    }

    func isPrinterConnect() -> String{
        if self.connection?.isConnected() == true {
            setStatus(message: connectedStr, color: "G")
              return connectedStr
        }
        else {
            setStatus(message: disconnectedStr, color: "R")
              return disconnectedStr
        }
    }

    func setSettings(settings: NSString){
        printData(data: settings)
    }

    func disconnect() {
        setStatus(message: disconnectingStr, color: "Y")
        if self.connection != nil {
            self.connection?.close()
        }
        setStatus(message: disconnectedStr, color: "R")
    }

   func printData(data: NSString) {
    //ToDo improve sending data
     DispatchQueue.global(qos: .utility).async {
      let dataBytes = Data(bytes: data.utf8String!, count: data.length)
      DispatchQueue.main.async {
                self.setStatus(message: "Sending Data", color: "Y")
             }
      var error: NSError?
      let result = self.connection?.write(dataBytes, error: &error)
      if result == -1, let error = error {
       print(error)
      }
      sleep(1)
        DispatchQueue.main.async {
            self.setStatus(message: self.doneStr, color: "G")
        }
     }
    }

    func setStatus(message: String, color: String){
        let data: [String: Any] = [
            "Status": message,
            "Color": color
        ]
        self.methodChannel?.invokeMethod("changePrinterStatus", arguments: data)

    }

}

==> zebrautility-0.0.10.tar.gz: ios/Classes/Printer.swift <==
//
//  Printer.swift
//  Runner
//
//  Created by faranegar on 6/21/20.
//

import Foundation


class Printer{

    let connectedStr:String = "Connected"
    let disconnectedStr:String = "Disconnected"
    let disconnectingStr:String = "Disconnecting"
    let sendingDataStr:String = "Sending Data"
    let doneStr:String = "Done"
    var connection : ZebraPrinterConnection?
    var methodChannel : FlutterMethodChannel?
    var selectedIPAddress: String? = nil
    var selectedMacAddress: String? = nil
    
    static func getInsatnce(binaryMessenger : FlutterBinaryMessenger) -> Printer {
        var printer = Printer()
        printer.setMethodChannel(binaryMessenger: binaryMessenger)
        return printer
    }
    
    func discoveryPrinters(){
      let manager = EAAccessoryManager.shared()
      let devices = manager.connectedAccessories
      for d in devices {
        self.methodChannel?.invokeMethod("printerFound", arguments: d.name + ";B_" + d.serialNumber)
      }
        self.methodChannel?.invokeMethod("onPrinterDiscoveryDone", arguments: nil)
    }
    
    func setMethodChannel(binaryMessenger : FlutterBinaryMessenger) {
        self.methodChannel = FlutterMethodChannel(name: "ZebraPrinterObject" + toString(), binaryMessenger: binaryMessenger)
        self.methodChannel?.setMethodCallHandler({ (FlutterMethodCall,  FlutterResult) in
            let args = FlutterMethodCall.arguments
            let myArgs = args as? [String: Any]
            if(FlutterMethodCall.method == "print"){
                self.printData(data: myArgs?["Data"] as! NSString)
            } else if(FlutterMethodCall.method == "checkPermission"){
                FlutterResult(true)
            } else if(FlutterMethodCall.method == "disconnect"){
                DispatchQueue.global(qos: .utility).async {
                    self.disconnect()
                          }
            } else if(FlutterMethodCall.method == "isPrinterConnected") {
                     FlutterResult(self.isPrinterConnect())
            } else if(FlutterMethodCall.method == "discoverPrinters") {
                self.discoveryPrinters()
            } else if(FlutterMethodCall.method == "setSettings") {
                let settingCommand = myArgs?["SettingCommand"] as? NSString
                        self.setSettings(settings: settingCommand!)
            } else if(FlutterMethodCall.method == "connectToPrinter") {
                   let address = myArgs?["address"] as? String
                DispatchQueue.global(qos: .utility).async { self.connectToSelectPrinter(address: address!)
                             }
            }
        })
    }

    func toString() -> String{
        return String(UInt(bitPattern: ObjectIdentifier(self)))
    }
    
    func connectToSelectPrinter(address: String) -> Bool{
        selectedIPAddress = nil

        if(self.connection != nil){
            self.connection?.close()
            setStatus(message: disconnectedStr, color: "R")
        }
        if(address.contains(":")){
            self.connection = MfiBtPrinterConnection(serialNumber: address)

        }else {
           self.connection = TcpPrinterConnection(address: address, andWithPort: 9100)
        }
        Thread.sleep(forTimeInterval: 1)
        let isOpen = self.connection?.open()
             print("connection open ")
        if isOpen == true {
           Thread.sleep(forTimeInterval: 1)
            self.selectedIPAddress = address
            setStatus(message: connectedStr, color: "G")
            return true
        } else {
            setStatus(message: disconnectedStr, color: "R")
            return false
        }
    }

    func isPrinterConnect() -> String{
        if self.connection?.isConnected() == true {
            setStatus(message: connectedStr, color: "G")
              return connectedStr
        }
        else {
            setStatus(message: disconnectedStr, color: "R")
              return disconnectedStr
        }
    }

    func setSettings(settings: NSString){
        printData(data: settings)
    }

    func disconnect() {
        setStatus(message: disconnectingStr, color: "Y")
        if self.connection != nil {
            self.connection?.close()
        }
        setStatus(message: disconnectedStr, color: "R")
    }

   func printData(data: NSString) {
    //ToDo improve sending data
     DispatchQueue.global(qos: .utility).async {
      let dataBytes = Data(bytes: data.utf8String!, count: data.length)
      DispatchQueue.main.async {
                self.setStatus(message: "Sending Data", color: "Y")
             }
      var error: NSError?
      let result = self.connection?.write(dataBytes, error: &error)
      if result == -1, let error = error {
        print(error)
        self.disconnect()
      }
      sleep(1)
        DispatchQueue.main.async {
            self.setStatus(message: self.doneStr, color: "G")
        }
     }
    }

    func setStatus(message: String, color: String){
        let data: [String: Any] = [
            "Status": message,
            "Color": color
        ]
        self.methodChannel?.invokeMethod("changePrinterStatus", arguments: data)

    }

}
